@@ -30,7 +30,6 @@ const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
-const Application = imports.application;
 const AudioProfile = imports.audioProfile;
 const MainWindow = imports.mainWindow;
 const Listview = imports.listview;
@@ -314,10 +313,6 @@ const BuildFileName = new Lang.Class({
     buildInitialFilename: function() {
         let fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
         let dir = Gio.Application.get_default().saveDir;
-        if (dir == null) {
-            Application.ensure_directory();
-            dir = Gio.Application.get_default().saveDir;
-        }
         this.dateTime = GLib.DateTime.new_now_local();
         this.clipNumber = Listview.trackNumber + 1;
         this.clipNumberString = this.clipNumber.toString();
